<?php

namespace Drupal\Tests\broadstreet_ads\Functional;

use Drupal\Tests\BrowserTestBase;
use Drupal\user\Entity\User;

/**
 * Confirm the basic functionality works.
 *
 * @group broadstreet_ads
 */
class AdsWorkflow extends BrowserTestBase {

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    // Modules for core functionality.
    'block',
    'field',
    'field_ui',
    'help',
    'node',
    'user',

    // Views. Duh. Enable the Views UI so it can be fully tested.
    'views',

    // This module.
    'broadstreet_ads',
  ];

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'claro';

  /**
   * Log in as user 1.
   *
   * @return \Drupal\user\Entity\User
   *   The full user object for user 1, after logging in.
   */
  protected function loginUser1() {
    // Load user 1.
    /** @var \Drupal\user\Entity\User $account */
    $account = User::load(1);

    // Reset the password.
    $password = 'foo';
    $account->setPassword($password)->save();

    // Support old and new tests.
    $account->passRaw = $password;
    $account->pass_raw = $password;

    // Login.
    $this->drupalLogin($account);

    return $account;
  }

  /**
   * Confirm the basic workflow of configuring the module.
   */
  public function testAdmin() {
    $this->loginUser1();

    // @todo Confirm there are no ad zones present when the module is installed.
    $this->drupalGet('/admin/structure/block');
    $this->assertSession()->statusCodeEquals(200);

    // Load the settings form, confirm it works as expected.
    $this->drupalGet('/admin/config/services/broadstreet-ads');
    $this->assertSession()->statusCodeEquals(200);
    $this->assertSession()->fieldExists('zones');

    $ad_code = $this->randomString();
    $ad_label = 'Ad 1';
    $edit = [
      'zones' => $ad_code . ':' . $ad_label,
    ];
    $this->submitForm($edit, 'Save');

    // Confirm the form saved correctly.
    $this->assertSession()->statusCodeEquals(200);
    $this->assertSession()->pageTextContains('The configuration options have been saved.');

    // @todo Confirm the ad zones are created.
    $this->drupalGet('/admin/structure/block');
    $this->assertSession()->statusCodeEquals(200);
  }

}
